#!/usr/bin/env node
'use strict';
const webpack = require('webpack');
const program = require('commander');
const packageJson = require('../package.json');
const path = require('path');
program
  .version(packageJson.version)
  .option('-c, --config <configPath>', 'mode: vue_h5,vue_dashboard')
  .parse(process.argv);

let webpackConfig;
if (program.config === 'vue_h5') {
  webpackConfig = require(path.join(__dirname, '../vue_h5/webpack.prod.js'));
} else {
  webpackConfig = require(path.join(__dirname, '../vue_dashboard/webpack.prod.js'));
}

webpack(webpackConfig, (err, stats) => {
  if (err) {
    console.error(err.stack || err);
    if (err.details) {
      console.error(err.details);
    }
    return;
  }

  const info = stats.toJson();

  if (stats.hasErrors()) {
    console.error(info.errors);
  }

  if (stats.hasWarnings()) {
    console.warn(info.warnings);
  }

  console.log(stats.toString({
    colors: true,
  }));
});
